summaryrefslogtreecommitdiff
path: root/include/gras
diff options
context:
space:
mode:
Diffstat (limited to 'include/gras')
-rw-r--r--include/gras/top_block.hpp5
1 files changed, 3 insertions, 2 deletions
diff --git a/include/gras/top_block.hpp b/include/gras/top_block.hpp
index 34ee98d..fc86e30 100644
--- a/include/gras/top_block.hpp
+++ b/include/gras/top_block.hpp
@@ -78,10 +78,11 @@ struct GRAS_API TopBlock : HierBlock
virtual bool wait(const double timeout);
/*!
* Get block usage statistics in XML format.
* An external app will visualize the data.
*/
- virtual std::string get_stats_xml(void);
+ virtual std::string get_stats(const std::string &args);
};
} //namespace gras
@@ -78,10 +78,11 @@ struct GRAS_API TopBlock : HierBlock
virtual bool wait(const double timeout);
/*!
- * Get block usage statistics in XML format.
+ * Get block usage statistics in some format.
+ * Args are used to set the query parameters.
* An external app will visualize the data.
*/